==> knative-model-4.6.4-sources.jar: io/fabric8/knative/eventing/v1alpha1/BrokerStatusFluent.java <==
package io.fabric8.knative.eventing.v1alpha1;

import io.fabric8.knative.v1.Condition;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.knative.duck.v1alpha1.AddressableFluent;
import io.fabric8.knative.v1.ConditionFluent;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.knative.v1.ConditionBuilder;
import io.fabric8.kubernetes.api.model.ObjectReference;
import java.lang.Deprecated;
import io.fabric8.knative.duck.v1alpha1.AddressableBuilder;
import java.lang.Long;
import io.fabric8.knative.duck.v1alpha1.Addressable;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface BrokerStatusFluent<A extends BrokerStatusFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildAddress instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.knative.duck.v1alpha1.Addressable getAddress();
    public io.fabric8.knative.duck.v1alpha1.Addressable buildAddress();
    public A withAddress(io.fabric8.knative.duck.v1alpha1.Addressable address);
    public Boolean hasAddress();
    public BrokerStatusFluent.V1alpha1AddressNested<A> withNewV1alpha1Address();
    public BrokerStatusFluent.V1alpha1AddressNested<A> withNewAddressLike(io.fabric8.knative.duck.v1alpha1.Addressable item);
    public BrokerStatusFluent.V1alpha1AddressNested<A> editV1alpha1Address();
    public BrokerStatusFluent.V1alpha1AddressNested<A> editOrNewAddress();
    public BrokerStatusFluent.V1alpha1AddressNested<A> editOrNewAddressLike(io.fabric8.knative.duck.v1alpha1.Addressable item);
    public A addToConditions(int index,Condition item);
    public A setToConditions(int index,Condition item);
    public A addToConditions(Condition... items);
    public A addAllToConditions(Collection<Condition> items);
    public A removeFromConditions(Condition... items);
    public A removeAllFromConditions(Collection<Condition> items);
    
/**
 * This method has been deprecated, please use method buildConditions instead.
 * @return The buildable object.
 */
@Deprecated public List<Condition> getConditions();
    public List<Condition> buildConditions();
    public Condition buildCondition(int index);
    public Condition buildFirstCondition();
    public Condition buildLastCondition();
    public Condition buildMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    public Boolean hasMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    public A withConditions(List<Condition> conditions);
    public A withConditions(Condition... conditions);
    public Boolean hasConditions();
    public BrokerStatusFluent.ConditionsNested<A> addNewCondition();
    public BrokerStatusFluent.ConditionsNested<A> addNewConditionLike(Condition item);
    public BrokerStatusFluent.ConditionsNested<A> setNewConditionLike(int index,Condition item);
    public BrokerStatusFluent.ConditionsNested<A> editCondition(int index);
    public BrokerStatusFluent.ConditionsNested<A> editFirstCondition();
    public BrokerStatusFluent.ConditionsNested<A> editLastCondition();
    public BrokerStatusFluent.ConditionsNested<A> editMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    public ObjectReference getIngressChannel();
    public A withIngressChannel(ObjectReference ingressChannel);
    public Boolean hasIngressChannel();
    public Long getObservedGeneration();
    public A withObservedGeneration(Long observedGeneration);
    public Boolean hasObservedGeneration();
    public ObjectReference getTriggerChannel();
    public A withTriggerChannel(ObjectReference triggerChannel);
    public Boolean hasTriggerChannel();

    public interface V1alpha1AddressNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.knative.duck.v1alpha1.AddressableFluent<BrokerStatusFluent.V1alpha1AddressNested<N>>{

        
    public N and();    public N endV1alpha1Address();
}
    public interface ConditionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ConditionFluent<BrokerStatusFluent.ConditionsNested<N>>{

        
    public N and();    public N endCondition();
}


}

==> knative-model-4.7.0-sources.jar: io/fabric8/knative/eventing/v1alpha1/BrokerStatusFluent.java <==
package io.fabric8.knative.eventing.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ObjectReference;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.knative.v1.Condition;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.knative.duck.v1alpha1.AddressableFluent;
import io.fabric8.knative.v1.ConditionFluent;
import io.fabric8.knative.v1.ConditionBuilder;
import io.fabric8.knative.duck.v1alpha1.AddressableBuilder;
import java.lang.Long;
import io.fabric8.knative.duck.v1alpha1.Addressable;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface BrokerStatusFluent<A extends BrokerStatusFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildAddress instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.knative.duck.v1alpha1.Addressable getAddress();
    public io.fabric8.knative.duck.v1alpha1.Addressable buildAddress();
    public A withAddress(io.fabric8.knative.duck.v1alpha1.Addressable address);
    public Boolean hasAddress();
    public BrokerStatusFluent.V1alpha1AddressNested<A> withNewV1alpha1Address();
    public BrokerStatusFluent.V1alpha1AddressNested<A> withNewAddressLike(io.fabric8.knative.duck.v1alpha1.Addressable item);
    public BrokerStatusFluent.V1alpha1AddressNested<A> editV1alpha1Address();
    public BrokerStatusFluent.V1alpha1AddressNested<A> editOrNewAddress();
    public BrokerStatusFluent.V1alpha1AddressNested<A> editOrNewAddressLike(io.fabric8.knative.duck.v1alpha1.Addressable item);
    public A addToConditions(int index,Condition item);
    public A setToConditions(int index,Condition item);
    public A addToConditions(Condition... items);
    public A addAllToConditions(Collection<Condition> items);
    public A removeFromConditions(Condition... items);
    public A removeAllFromConditions(Collection<Condition> items);
    public A removeMatchingFromConditions(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildConditions instead.
 * @return The buildable object.
 */
@Deprecated public List<Condition> getConditions();
    public List<Condition> buildConditions();
    public Condition buildCondition(int index);
    public Condition buildFirstCondition();
    public Condition buildLastCondition();
    public Condition buildMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    public Boolean hasMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    public A withConditions(List<Condition> conditions);
    public A withConditions(Condition... conditions);
    public Boolean hasConditions();
    public BrokerStatusFluent.ConditionsNested<A> addNewCondition();
    public BrokerStatusFluent.ConditionsNested<A> addNewConditionLike(Condition item);
    public BrokerStatusFluent.ConditionsNested<A> setNewConditionLike(int index,Condition item);
    public BrokerStatusFluent.ConditionsNested<A> editCondition(int index);
    public BrokerStatusFluent.ConditionsNested<A> editFirstCondition();
    public BrokerStatusFluent.ConditionsNested<A> editLastCondition();
    public BrokerStatusFluent.ConditionsNested<A> editMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<ConditionBuilder> predicate);
    public ObjectReference getIngressChannel();
    public A withIngressChannel(ObjectReference ingressChannel);
    public Boolean hasIngressChannel();
    public Long getObservedGeneration();
    public A withObservedGeneration(Long observedGeneration);
    public Boolean hasObservedGeneration();
    public ObjectReference getTriggerChannel();
    public A withTriggerChannel(ObjectReference triggerChannel);
    public Boolean hasTriggerChannel();

    public interface V1alpha1AddressNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.knative.duck.v1alpha1.AddressableFluent<BrokerStatusFluent.V1alpha1AddressNested<N>>{

        
    public N and();    public N endV1alpha1Address();
}
    public interface ConditionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ConditionFluent<BrokerStatusFluent.ConditionsNested<N>>{

        
    public N and();    public N endCondition();
}


}
